@@ -1,4 +1,4 @@
-# $Id: windfinder.py 1156 2014-12-03 19:44:45Z mwall $
+# $Id: windfinder.py 1173 2014-12-07 15:25:10Z mwall $
 # Copyright 2014 Matthew Wall
 
 """
@@ -36,7 +36,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.4"
+VERSION = "0.5"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -122,10 +122,11 @@ class WindFinderThread(weewx.restx.RESTThread):
 
     def process_record(self, record, dbm):
         r = self.get_record(record, dbm)
+        if 'windSpeed' not in r or r['windSpeed'] is None:
+            raise weewx.restx.FailedPost("No windSpeed in record")
         url = self.get_url(r)
         if self.skip_upload:
-            loginf("skipping upload")
-            return
+            raise weewx.restx.FailedPost("Upload disabled for this service")
         req = urllib2.Request(url)
         req.add_header("User-Agent", "weewx/%s" % weewx.__version__)
         self.post_with_retries(req)
